/****************************************************************************
**
** Copyright (C) 2019 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Design Viewer of the Qt Toolkit.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include <android/log.h>
#include <QApplication>
#include <QMessageBox>
#include <QQmlContext>

#include "backend.h"

static Backend *backend;
static QString appLogs;

void messageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
{
    QString logPrefix, logSuffix, newLog;

    QByteArray localMsg = msg.toLocal8Bit();
    const char *file = context.file ? context.file : "";
    const char *function = context.function ? context.function : "";

    switch (type) {
    case QtDebugMsg:
        logPrefix = QStringLiteral("Debug: ");
        break;
    case QtInfoMsg:
        logPrefix = QStringLiteral("Info: ");
        break;
    case QtWarningMsg:
        logPrefix = QStringLiteral("Warning: ");
        break;
    case QtCriticalMsg:
        logPrefix = QStringLiteral("Critical: ");
        break;
    case QtFatalMsg:
        logPrefix = QStringLiteral("Fatal: ");
        logSuffix = QStringLiteral(" (%1:%2, %3)").arg(file).arg(context.line).arg(function);
        break;
    }

    newLog += logPrefix + localMsg + logSuffix + "\n";
    __android_log_print(ANDROID_LOG_DEBUG, "Qt_UI_Viewer", "%s", qPrintable(newLog));

    // only show critical and fatal messages in the UI
    if (type == QtCriticalMsg || type == QtFatalMsg) {
        QMessageBox msgBox{QMessageBox::Critical, "Critical:", msg, QMessageBox::Ok};
        msgBox.exec();
        if (backend)
            backend->setLogs(appLogs += newLog);
    }
}

int main(int argc, char *argv[])
{
    qInstallMessageHandler(messageHandler);
    QApplication app(argc, argv);
    QApplication::setOrganizationName("Qt");
    QApplication::setApplicationName(QStringLiteral("Qt Design Viewer"));
    QApplication::setApplicationVersion(QString("Built on %1 %2").arg(__DATE__, __TIME__));

    QQuickView view;
    backend = new Backend();

    view.engine()->rootContext()->setContextProperty("backend", backend);
    view.setSource(QUrl(QStringLiteral("qrc:/main.qml")));
    view.setResizeMode(QQuickView::SizeRootObjectToView);
    view.showMaximized();

    backend->initialize();
    return app.exec();
}
