import QtQuick
import QtQuick.Controls 6.4
import QtQuick.Layouts


Item {
    id: homePage
    //width: 400
    //height: 740

    ColumnLayout {
        anchors.fill: parent


        Item {
            id: item2
            Layout.preferredWidth: 10
            Layout.preferredHeight: 10
            Layout.fillWidth: true
            Layout.fillHeight: true
        }

        Text {
            id: qrCodeStatus
            text: qsTr("No user code is registered.\nTo access your shared projects;")
            font.pixelSize: 12
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            Layout.fillWidth: true
            Connections {
                target: backend
                function onUserRegistered(){
                    qrCodeStatus.text = "QR Code Registered\nYou can simply scan a new QR code to register another user.";
                    qrCodeInstructions.text = "";
                }
            }
        }

        Text {
            id: qrCodeInstructions
            text: qsTr("1. Open Design Studio (4.4 or later)\n2. Open any project\n3. Click \"File\" menu from top\n4. Select \"Share Application Online\"\n5. Scan QR code with your camera or any QR reader app")
            font.pixelSize: 12
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            Layout.fillWidth: true
        }

        ColumnLayout {
            id: column2
            Layout.fillWidth: true
            ComboBox {
                id: projectList
                Layout.fillWidth: true
                onCurrentIndexChanged: {
                    displayText = textAt(currentIndex)
                    downloadUserProject.enabled = true
                }
                onModelChanged: {
                    if (model.count > 0) {
                        currentIndex = 0
                    }
                }
                model: backend.projectList
                down: false
                displayText: "Select project..."
                currentIndex: -1
                Layout.preferredHeight: 50
            }

            Button {
                id: downloadUserProject
                text: qsTr("Run Project")
                onClicked: backend.runUserProject(projectList.currentText)
                enabled: backend.userHash !== ''
                Layout.fillWidth: true
                Layout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
            }
        }



        Item {
            id: item3
            Layout.fillHeight: true
            Layout.fillWidth: true
            Layout.preferredHeight: 10
            Layout.preferredWidth: 10
        }



        ColumnLayout {
            id: column
            Layout.fillWidth: true

            Text {
                id: downloadInstructions
                text: qsTr("Enter project URL and then click the button below")
                font.pixelSize: 12
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                Layout.fillWidth: true
            }

            TextField {
                id: urlTextField
                horizontalAlignment: Text.AlignHCenter
                placeholderText: qsTr("Enter URL")
                Layout.fillWidth: true
                Layout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
            }

            RowLayout {
                id: rowLayout
                Button {
                    id: downloadButton
                    text: qsTr("Download and Run Project")
                    onClicked: backend.runOnlineProject(urlTextField.text)
                    enabled: urlTextField.text !== ''
                    Layout.fillWidth: true
                    Layout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
                }
            }

            Connections {
                target: backend
                function onUrlUpdated(newUrl){
                    urlTextField.text = newUrl;
                }
            }
        }
    }
}
